<?php
if (!function_exists('is_admin')) {
    header('Status: 403 Forbidden');
    header('HTTP/1.1 403 Forbidden');
    exit();
}

if (!class_exists("scoilnetResources_settings")) :

    /*
      Create example settings page for our plugin.

      - We show how to render our own controls using HTML.
      - We show how to get WordPress to render controls for us using do_settings_sections'

      WordPress Settings API tutorials
      http://codex.wordpress.org/Settings_API
      http://ottopress.com/2009/wordpress-settings-api-tutorial/
     */

    class scoilnetResources_settings {

        public static $default_settings = array(
            "client_id" => "Your Client ID Here...",
            "client_secret" => "Your Client Secret Here...",
            "api_key" => "The API Key Here..."
        );
        var $pagehook, $page_id, $settings_field, $options;

        function __construct() {
            $this->page_id = 'scoilnetResources';
            // This is the get_options slug used in the database to store our plugin option values.
            $this->settings_field = 'scoilnetResources_options';
            $this->options = get_option($this->settings_field);

            add_action('admin_init', array($this, 'admin_init'), 20);
            add_action('admin_menu', array($this, 'admin_menu'), 20);
        }

        function admin_init() {
            register_setting($this->settings_field, $this->settings_field, array($this, 'sanitize_theme_options'));
            add_option($this->settings_field, scoilnetResources_settings::$default_settings);


            /*
              This is needed if we want WordPress to render our settings interface
              for us using -
              do_settings_sections

              It sets up different sections and the fields within each section.
             */
            add_settings_section('scoilnetResources', '', array($this, 'main_section_text'), 'OAuth_settings_page');

            add_settings_field('_client_id', 'Client Id', array($this, 'render_client_id'), 'OAuth_settings_page', 'scoilnetResources');
            add_settings_field('_client_secret', 'Client Secret', array($this, 'render_client_secret'), 'OAuth_settings_page', 'scoilnetResources');
            add_settings_field('_api_key', 'API Key', array($this, 'render_api_key'), 'OAuth_settings_page', 'scoilnetResources');

            add_settings_section('scoilnetResources', '', array($this, 'main_section_text'), 'DefaultSearch_settings_page');

            add_settings_field('searchResultsPageUrl', 'Search Results Page', array($this, 'render_searchresultspageurl'), 'DefaultSearch_settings_page', 'scoilnetResources');
            add_settings_field('school_level', 'School Level', array($this, 'render_schoolLevel'), 'DefaultSearch_settings_page', 'scoilnetResources');
            add_settings_field('school_grade', 'School Grade', array($this, 'render_schoolGrade'), 'DefaultSearch_settings_page', 'scoilnetResources');
            add_settings_field('school_discipline', 'School Subject', array($this, 'render_schoolDiscipline'), 'DefaultSearch_settings_page', 'scoilnetResources');
            add_settings_field('school_topic', 'School Strand', array($this, 'render_schoolTopic'), 'DefaultSearch_settings_page', 'scoilnetResources');
            add_settings_field('school_subtopic', 'School Strand Unit', array($this, 'render_schoolSubTopic'), 'DefaultSearch_settings_page', 'scoilnetResources');
            add_settings_field('resource_language', 'Resource Language', array($this, 'render_resourceLanguage'), 'DefaultSearch_settings_page', 'scoilnetResources');
            add_settings_field('resource_resourcetype', 'Resource Type', array($this, 'render_resourceType'), 'DefaultSearch_settings_page', 'scoilnetResources');
            add_settings_field('limit', 'Limit', array($this, 'render_limit'), 'DefaultSearch_settings_page', 'scoilnetResources');
            //add_settings_field('sort', 'Sort by', array($this, 'render_sort'), 'DefaultSearch_settings_page', 'scoilnetResources');
            add_settings_field('lang', 'Language', array($this, 'render_lang'), 'DefaultSearch_settings_page', 'scoilnetResources');
        }

        function admin_menu() {
            if (!current_user_can('update_plugins'))
                return;

            // Add a new submenu to the standard Settings panel
            $this->pagehook = $page = add_options_page(
                    __('Scoilnet Resources', 'scoilnetResources'), __('Scoilnet Resources', 'scoilnetResources'), 'administrator', $this->page_id, array($this, 'render'));

            // Executed on-load. Add all metaboxes.
            add_action('load-' . $this->pagehook, array($this, 'metaboxes'));

            // Include js, css, or header *only* for our settings page
            add_action("admin_print_scripts-$page", array($this, 'js_includes'));
            add_action("admin_head-$page", array($this, 'admin_head'));
        }

        function admin_head() {
            ?>
            <style>
                .settings_page_scoilnetResources label { display:inline-block; width: 150px; }
            </style>
        <?php
        }

        function js_includes() {
            // Needed to allow metabox layout and close functionality.
            wp_enqueue_script('postbox');
            wp_enqueue_script('select2', scoilnetResources_URL . 'js/select2/select2.min.js', array('jquery'), false, false);
            wp_enqueue_style('select2', scoilnetResources_URL . 'js/select2/select2.css', false);
            wp_enqueue_script('scoilnetResources', scoilnetResources_URL . 'js/scoilnet-resouces-admin.js', array('jquery', 'select2'), false, true);
        }

        /*
          Sanitize our plugin settings array as needed.
         */

        function sanitize_theme_options($options) {
            $options['example_text'] = stripcslashes($options['example_text']);
            return $options;
        }

        /*
          Settings access functions.

         */

        protected function get_field_name($name) {

            return sprintf('%s[%s]', $this->settings_field, $name);
        }

        protected function get_field_id($id) {

            return sprintf('%s[%s]', $this->settings_field, $id);
        }

        protected function get_field_value($key) {

            return $this->options[$key];
        }

        /*
          Render settings page.

         */

        function render() {
            global $wp_meta_boxes;

            $title = __('Scoilnet Resources Settings', 'scoilnetResources');
            ?>
            <div class="wrap">   
                <h2><?php echo esc_html($title); ?> <img style="float: right" src="<?php echo plugins_url('images/scoilnet-tiny-logo.png', __FILE__); ?>"></h2>

                <form method="post" action="options.php">
                    <p>
                        <input type="submit" class="button button-primary" name="save_options" value="<?php esc_attr_e('Save Options'); ?>" />
                    </p>

                    <div class="metabox-holder">
                        <div class="postbox-container" style="width: 99%;">
            <?php
            // Render metaboxes
            settings_fields($this->settings_field);
            do_meta_boxes($this->pagehook, 'main', null);
            if (isset($wp_meta_boxes[$this->pagehook]['column2']))
                do_meta_boxes($this->pagehook, 'column2', null);
            ?>
                        </div>
                    </div>

                    <p>
                        <input type="submit" class="button button-primary" name="save_options" value="<?php esc_attr_e('Save Options'); ?>" />
                    </p>
                </form>
            </div>

            <!-- Needed to allow metabox layout and close functionality. -->
            <script type="text/javascript">
                //<![CDATA[
                jQuery(document).ready(function($) {


                    // close postboxes that should be closed
                    $('.if-js-closed').removeClass('if-js-closed').addClass('closed');
                    // postboxes setup
                    postboxes.add_postbox_toggles('<?php echo $this->pagehook; ?>');
                });
                //]]>
            </script>
        <?php
        }

        function metaboxes() {

            // Example metabox showing plugin version and release date. 
            // Also includes and example input text box, rendered in HTML in the info_box function
            add_meta_box('scoilnetResources-version', __('Information', 'scoilnetResources'), array($this, 'info_box'), $this->pagehook, 'main', 'high');

            // Example metabox containing two example checkbox controls.
            // Also includes and example input text box, rendered in HTML in the condition_box function
            ////add_meta_box( 'shiba-example-conditions', __( 'Example Conditions', 'scoilnetResources' ), array( $this, 'condition_box' ), $this->pagehook, 'main' );
            // Example metabox containing an example text box & two example checkbox controls.
            // Example settings rendered by WordPress using the do_settings_sections function.
            ////add_meta_box( 	'shiba-example-all', 
            ////				__( 'Rendered by WordPress using do_settings_sections', 'scoilnetResources' ), 
            ////				array( $this, 'do_settings_box' ), $this->pagehook, 'main' );

            add_meta_box('scoilnetResources-OAuth', __('OAuth Details', 'scoilnetResources'), array($this, 'do_settings_box'), $this->pagehook, 'main');

            add_meta_box('scoilnetResources-SearchSetting', __('Default Search Settings', 'scoilnetResources'), array($this, 'do_searchSettings_box'), $this->pagehook, 'main');

            add_meta_box('scoilnetResources-ShortcodesHelp', __('Displaying the resources and search box', 'scoilnetResources'), array($this, 'shortcodes_box'), $this->pagehook, 'main');
        }

        function info_box() {
            ?>

            <p><strong><?php _e('Welcome to the Scoilnet Resources Wordpress plugin.', 'scoilnetResources'); ?></strong></p>
            <p><?php _e('With this plugin you can access over 10,000 resources and add them to your own site. To get started follow these steps below.', 'scoilnetResources'); ?></p>


            <li><a href="https://www.scoilnet.ie/scoilnet-api/application-management/"><?php _e('Login ', 'scoilnetResources'); ?></a>
            <?php _e('with you teacher account. If you are a developer and do not have access to a teacher account please'); ?>
                <a href="https://www.scoilnet.ie/scoilnet/contact-us/"><?php _e(' contact us ', 'scoilnetResources'); ?></a>
            <?php _e('and we will create a developers account for you.', 'scoilnetResources'); ?></li>

            <li><?php _e('Generate an application key for your website', 'scoilnetResources'); ?></li>

            <li><?php _e('Fill in the OAuth Details in the box below', 'scoilnetResources'); ?></li>

            <li><?php _e('Optionally, set the filters in Default Search Settings box below. These are default settings that might be overwritten by the [getScoilnetResults] shortcode parameters.', 'scoilnetResources'); ?></li>

            <li><?php _e('Create a new page and paste the [getScoilnetResults] shortcode into the content area. You can also use the Scoilnet button available from the WYSIWYG in visual mode to insert the shortcode.', 'scoilnetResources'); ?></li>

            <li><?php _e('Set the newly created page as the Search Results Page in the Default Search Settings box below', 'scoilnetResources'); ?></li>

            <li><?php _e('Go to Appearance->Widgets and put the Scoilnet Resources Searchbox Widget into one of your widget areas. You can also use the Scoilnet button available from the WYSIWYG in visual mode to insert the shortcode for the search box and insert it into any page or post.', 'scoilnetResources'); ?></li>

            <p><strong><?php _e('Version:', 'scoilnetResources'); ?></strong> 
            <?php echo scoilnetResources_VERSION; ?> <?php echo '&middot;'; ?> 
                <strong><?php _e('Released:', 'scoilnetResources'); ?></strong> 
            <?php echo scoilnetResources_RELEASE_DATE; ?></p>		
            <?php
        }

        function shortcodes_box() {
            ?>
            <p>Copy and paste this shortcodes directly into the page or widget where you would like the resources or search box to show up:</p>
            <table class="widefat">
                <thead>
                    <tr>
                        <th class="row-title">Shortcode</th>
                        <th>Explanation</th>
                        <th>Example usage</th>
                    </tr>
                </thead>
                <tbody>
                    <tr valign="top">
                        <td><input type="text" size="20"  value="[getScoilnetResults]" readonly onclick="this.focus();
                                this.select()" title="To copy, click the field then press Ctrl + C (PC) or Cmd + C (Mac)."></td>
                        <td>Create a new page eg. Scoilnet Search Results and paste the shortcode into its content. To limit or filter the search results shown you can use all the parameters available in the <a href="https://www.scoilnet.ie/scoilnet-api/documentation/">Scoilnet API documentation</a>.</td>
                        <td style="width:50%">[getScoilnetResults q="World War 2" school_grade="2"]</td>
                    </tr>			
                </tbody>
            </table>


            <?php
        }       

        function do_settings_box() {
            do_settings_sections('OAuth_settings_page');
        }

        function do_searchSettings_box() {
            do_settings_sections('DefaultSearch_settings_page');
        }

        function do_searchTest_box() {
            do_settings_sections('searchTest_box');
        }

        /*
          WordPress settings rendering functions

          ONLY NEEDED if we are using wordpress to render our controls (do_settings_sections)
         */

        function main_section_text() {
            ////echo '<p>Some example inputs.</p>';
        }

        function render_example_text() {
            
        }

        /*
          ?>
          <input id="example_text" style="width:50%;"  type="text" name="<?php echo $this->get_field_name( 'example_text' ); ?>" value="<?php echo esc_attr( $this->get_field_value( 'example_text' ) ); ?>" />
          <?php
          }
         */

        function render_client_id() {
            ?>
            <input id="_client_id" style="width:50%;"  type="text" name="<?php echo $this->get_field_name('_client_id'); ?>" value="<?php echo esc_attr($this->get_field_value('_client_id')); ?>" />
            <i style="color: #666; font-size: 13px;">You can generate one on scoilnet.ie after you login </i>
            <?php
        }

        function render_client_secret() {
            ?>
            <input id="_client_secret" style="width:50%;"  type="text" name="<?php echo $this->get_field_name('_client_secret'); ?>" value="<?php echo esc_attr($this->get_field_value('_client_secret')); ?>" />	
            <?php
        }

        function render_api_key() {
            ?>
            <input id="_api_key" style="width:50%;"  type="text" name="<?php echo $this->get_field_name('_api_key'); ?>" value="<?php echo esc_attr($this->get_field_value('_api_key')); ?>" />	
            <?php
        }

        function render_searchresultspageurl() {
            $args = array(
                'name' => $this->get_field_name('_searchResultsPageUrl'),
                'id' => $this->get_field_id('_searchResultsPageUrl'),
                'sort_column' => 'menu_order',
                'sort_order' => 'ASC',
                'show_option_none' => 'Select a page',
                'echo' => false,
                'selected' => esc_attr($this->get_field_value('_searchResultsPageUrl'))
            );

            if (isset($value['args'])) {
                $args = wp_parse_args($value['args'], $args);
            }

            echo wp_dropdown_pages($args);
            ?>
            <br><i style="color: #666; font-size: 13px;">Select the page where you want to show the search results after hitting search in the Scoilnet Search Box Widget. This page content should have the [getScoilnetResults] shortcode.</i>
            <?php
        }

        function render_schoolLevel() {
            ?>
            <input  class="school_level" id="school_level" style="width:50%;"  type="text" name="<?php echo $this->get_field_name('school_level'); ?>" value="<?php echo esc_attr($this->get_field_value('school_level')); ?>" />
            <?php
        }

        function render_schoolGrade() {
            ?>
            <input class="school_grade" id="school_grade" style="width:50%;"  type="text" name="<?php echo $this->get_field_name('school_grade'); ?>" value="<?php echo esc_attr($this->get_field_value('school_grade')); ?>" />	
            <?php
        }

        function render_schoolDiscipline() {
            ?>
            <input class="school_discipline"  id="school_discipline" style="width:50%;"  type="text" name="<?php echo $this->get_field_name('school_discipline'); ?>" value="<?php echo esc_attr($this->get_field_value('school_discipline')); ?>" />	
            <?php
        }

        function render_schoolTopic() {
            ?>
            <input class="school_topic"  id="school_topic" style="width:50%;"  type="text" name="<?php echo $this->get_field_name('school_topic'); ?>" value="<?php echo esc_attr($this->get_field_value('school_topic')); ?>" />	
            <?php
        }

        function render_schoolSubTopic() {
            ?>
            <input class="school_subtopic"  id="school_subtopic" style="width:50%;"  type="text" name="<?php echo $this->get_field_name('school_subtopic'); ?>" value="<?php echo esc_attr($this->get_field_value('school_subtopic')); ?>" />	
            <?php
        }

        function render_resourceLanguage() {
            ?>
            <input class="resource_language"  id="resource_language" style="width:50%;"  type="text" name="<?php echo $this->get_field_name('resource_language'); ?>" value="<?php echo esc_attr($this->get_field_value('resource_language')); ?>" />	
            <?php
        }

        function render_resourceType() {
            ?>
            <input class="resource_resourcetype"  id="resource_resourcetype" style="width:50%;"  type="text" name="<?php echo $this->get_field_name('resource_resourcetype'); ?>" value="<?php echo esc_attr($this->get_field_value('resource_resourcetype')); ?>" />	
            <?php
        }

        function render_limit() {
            ?>
            <input id="limit" style="width:5em;"  type="number" min="1" max="50" step="1" name="<?php echo $this->get_field_name('limit'); ?>" value="<?php echo esc_attr($this->get_field_value('limit')); ?>" />	
            <i style="color: #666; font-size: 13px;">Number of resources per page to return. Default is 20. Max is 50.</i>		
            <?php
        }
        
        
        function render_sort() {
            ?>
            <select id="sort" name="<?php echo $this->get_field_name('sort'); ?>">
                <option value="">Choose Sort Option</option>
                <option <?php if ('score' == $this->get_field_value('sort')) echo 'selected="selected"'; ?> value="score">Best match</option>
                <option <?php if ('creation_date' == $this->get_field_value('sort')) echo 'selected="selected"'; ?> value="creation_date">Most recent</option>
            </select>
            <!--<input id="sort" style="width:50%;"  type="text"  value="<?php echo esc_attr($this->get_field_value('sort')); ?>" /> -->
            <?php
        }

        function render_page() {
            ?>
            <input id="page" style="width:50%;"  type="text" name="<?php echo $this->get_field_name('page'); ?>" value="<?php echo esc_attr($this->get_field_value('page')); ?>" />	
            <?php
        }

        function render_lang() {
            ?>
            <select id="lang" name="<?php echo $this->get_field_name('lang'); ?>">
                <option value="">Choose Language</option>
                <option <?php if ('en' == $this->get_field_value('lang')) echo 'selected="selected"'; ?> value="en">English</option>
                <option <?php if ('ga' == $this->get_field_value('lang')) echo 'selected="selected"'; ?> value="ga">Gaeilge</option>
                <option <?php if ('fr' == $this->get_field_value('lang')) echo 'selected="selected"'; ?> value="fr">French</option>
                <option <?php if ('de' == $this->get_field_value('lang')) echo 'selected="selected"'; ?> value="de">German</option>
            </select>
            <i style="color: #666; font-size: 13px;">Language of the text results and facets. Default is English</i>
            <?php
        }

        function render_fieldset() {
            ?>
            <select id="fieldset" name="<?php echo $this->get_field_name('fieldset'); ?>">
                <option <?php if ('en' == $this->get_field_value('fieldset')) echo 'selected="selected"'; ?> value="default">Default</option>
                <option <?php if ('ga' == $this->get_field_value('fieldset')) echo 'selected="selected"'; ?> value="full">Full</option>
            </select>
            <i style="color: #666; font-size: 13px;">The resource data returned. Default will return a minimum amount of data. Full will return all the data for a resource.</i>
            <?php
        }        
    }

    // end class
endif;
?>