<?php
/*
  Plugin Name: Scoilnet Resources
  Plugin URI: https://www.scoilnet.ie/scoilnet-api/sdk/
  Description: Add Scoilnet.ie search into your Wordpress site. With this plugin you can access over 10,000 educational resources available on the <a href="https://www.scoilnet.ie">scoilnet.ie</a>.
  Version: 1.0.0
  Author: Scoilnet.ie
  Author URI: https://www.scoilnet.ie/
  License: GPLv2
 */
/*
  Copyright 2014 Scoilnet.ie
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

require 'scoilnetWPClient.php';

if (!function_exists('is_admin')) {
    header('Status: 403 Forbidden');
    header('HTTP/1.1 403 Forbidden');
    exit();
}

define('scoilnetResources_VERSION', '1.0.0');
define('scoilnetResources_RELEASE_DATE', date_i18n('F j, Y', '1412689988'));
define('scoilnetResources_DIR', plugin_dir_path(__FILE__));
define('scoilnetResources_URL', plugin_dir_url(__FILE__));

require_once( scoilnetResources_DIR . 'scoilnetResources_SearchBoxWidget.php' );
require_once( scoilnetResources_DIR . 'scoilnetResources_shortcodes.php' );
require_once( scoilnetResources_DIR . 'scoilnetResources_button.php' );


if (!class_exists("scoilnetResources")) :

    class scoilnetResources {

        var $settings, $options_page;
        protected $scoilnetClient;

        function __construct() {

            if (is_admin()) {
                // Load example settings page
                if (!class_exists("scoilnetResources_settings"))
                    require(scoilnetResources_DIR . 'scoilnetResources-settings.php');
                $this->settings = new scoilnetResources_Settings();
            }

            add_action('init', array($this, 'init'));
            add_action('admin_init', array($this, 'admin_init'));
            add_action('admin_menu', array($this, 'admin_menu'));

            register_activation_hook(__FILE__, array($this, 'activate'));
            register_deactivation_hook(__FILE__, array($this, 'deactivate'));
        }

        /*
          Propagates pfunction to all blogs within our multisite setup.
          More details -
          http://shibashake.com/wordpress-theme/write-a-plugin-for-wordpress-multi-site

          If not multisite, then we just run pfunction for our single blog.
         */

        function network_propagate($pfunction, $networkwide) {
            global $wpdb;

            if (function_exists('is_multisite') && is_multisite()) {
                // check if it is a network activation - if so, run the activation function 
                // for each blog id
                if ($networkwide) {
                    $old_blog = $wpdb->blogid;
                    // Get all blog ids
                    $blogids = $wpdb->get_col("SELECT blog_id FROM {$wpdb->blogs}");
                    foreach ($blogids as $blog_id) {
                        switch_to_blog($blog_id);
                        call_user_func($pfunction, $networkwide);
                    }
                    switch_to_blog($old_blog);
                    return;
                }
            }
            call_user_func($pfunction, $networkwide);
        }

        function activate($networkwide) {
            $this->network_propagate(array($this, '_activate'), $networkwide);
        }

        function deactivate($networkwide) {
            $this->network_propagate(array($this, '_deactivate'), $networkwide);
        }

        public function search() {

            $params = $this->getParams();

            if (!empty($params)) {
                $scoilnetResources_options = get_option('scoilnetResources_options');

                $this->scoilnetClient = new ScoilnetWPClient($scoilnetResources_options);

                $response = $this->scoilnetClient->search($params);               

                return $response;
            }
        }

        public function searchWithParameters($params, $userSessionParameters) {
            if (!empty($params)) {
                // override end points with these!
                $userSessionParameters['authorize_uri'] = "https://www.scoilnet.ie/oauth/v2/auth";
                $userSessionParameters['access_token_uri'] = "https://www.scoilnet.ie/oauth/v2/token";
                $userSessionParameters['base_uri'] = "https://www.scoilnet.ie/";

                $this->scoilnetClient = new ScoilnetWPClient($userSessionParameters);

                if (!empty($params['sr_page'])) {
                    $params['page'] = $params['sr_page'];
                }

                $response = $this->scoilnetClient->search($params);

                if ($response && ($response['success'] == true)) {
                    return $response;
                } else {
                    return null;
                }
            }
        }

        /**
         * Gets and filters all paramaters
         * @return array
         */
        public static function getParams() {
            $params = array();
            //echo INPUT_GET;
            //echo filter_input_array(INPUT_GET);
            $my_var = filter_input_array(INPUT_GET);
            if (!empty($my_var)) {
                foreach ($my_var as $paramName => $paramValue) {
                    $params[$paramName] = $paramValue;
                }
            }
            return $params;
        }

        /*
          Enter our plugin activation code here.
         */

        function _activate() {
            
        }

        /*
          Enter our plugin deactivation code here.
         */

        function _deactivate() {
            
        }

        /*
          Load language translation files (if any) for our plugin.
         */

        function init() {
            load_plugin_textdomain('scoilnetResources', scoilnetResources_DIR . 'lang', basename(dirname(__FILE__)) . '/lang');
            add_action('wp_enqueue_scripts', array($this, 'scoilnetresources_style'));
            add_action('wp_enqueue_scripts', array($this, 'scoilnetresources_scripts'));
        }

        public static function scoilnetresources_style() {
            wp_enqueue_style('core', scoilnetResources_URL . 'css/scoilnet-resources.css', false);
        }

        public static function scoilnetresources_scripts() {
            wp_enqueue_script('scoilnet-resources', scoilnetResources_URL . 'js/scoilnet-resources.js', array('jquery'), false, true);
        }

        function admin_init() {
            
        }

        function admin_menu() {
            
        }

        /*
          Example print function for debugging.
         */

        function print_example($str, $print_info = TRUE) {
            if (!$print_info)
                return;
            __($str . "<br/><br/>\n", 'scoilnetResources');
        }

        /*
          Redirect to a different page using javascript. More details-
          http://shibashake.com/wordpress-theme/wordpress-page-redirect
         */

        function javascript_redirect($location) {
            // redirect after header here can't use wp_redirect($location);
            ?>
            <script type="text/javascript">
            <!--
                window.location = <?php echo "'" . $location . "'"; ?>;
            //-->
            </script>
            <?php
            exit;
        }

    }

    // end class
endif;


// Initialize our plugin object.
global $scoilnetResources;
if (class_exists("scoilnetResources") && !$scoilnetResources) {
    $scoilnetResources = new scoilnetResources();
}	